attrs: Decorator for Python classes with attributes
===================================================

Description
-----------

attrs is the Python package that will bring back the joy of writing classes
by relieving you from the drudgery of implementing object protocols
(aka dunder methods).

License
-------

MIT License


Upstream Contact
----------------

Home page: https://www.attrs.org
